@@ -13,8 +13,8 @@
 #' be extracted using custom functions or manually from the original output of
 #' the model using the \code{model_output} entry of the lm_topic_labels object.
 #'
-#' Implemented default parameters for the models \code{HuggingFaceH4/zephyr-7b-beta},
-#' \code{tiiuae/falcon-7b-instruct}, and \code{mistralai/Mixtral-8x7B-Instruct-v0.1} are:
+#' Implemented default parameters for the models \code{google/gemma-2-2b-it} and
+#' \code{deepseek-ai/DeepSeek-V3.2-Exp:novita} are:
 #' \describe{
 #'   \item{\code{max_new_tokens}}{300}
 #'   \item{\code{return_full_text}}{\code{FALSE}}
@@ -46,8 +46,8 @@
 #' Optional.\cr
 #' The language model to use for labeling the topics.
 #' The model must be accessible via the Huggingface API. Default is
-#' \code{mistralai/Mixtral-8x7B-Instruct-v0.1}. Other promising models are
-#' \code{HuggingFaceH4/zephyr-7b-beta} or \code{tiiuae/falcon-7b-instruct}.
+#' \code{google/gemma-2-2b-it}. Another promising model is
+#' \code{deepseek-ai/DeepSeek-V3.2-Exp:novita}.
 #' To find more models see: https://huggingface.co/models?other=conversational&sort=likes.
 #' @param params [\code{named list}]\cr
 #' Optional.\cr
@@ -115,7 +115,7 @@ label_topics = function(...) UseMethod("label_topics")
 #' @export
 label_topics.default = function(
     terms,
-    model = "mistralai/Mixtral-8x7B-Instruct-v0.1",
+    model = "google/gemma-2-2b-it",
     params = list(),
     token = NA_character_,
     context = "",
